@@ -20,11 +20,11 @@
 #ifndef KHC_GLOSSARY_H
 #define KHC_GLOSSARY_H
 
-#include <QTreeWidget>
 #include <QDomElement>
-#include <QList>
 #include <QHash>
+#include <QList>
 #include <QProcess>
+#include <QTreeWidget>
 
 class EntryItem;
 
@@ -79,7 +79,7 @@ namespace KHC {
   {
     Q_OBJECT
     public:
-      Glossary( QWidget *parent );
+      explicit Glossary( QWidget *parent );
       virtual ~Glossary();
 
       const GlossaryEntry &entry( const QString &id ) const;
@@ -95,7 +95,7 @@ namespace KHC {
       void treeItemSelected( QTreeWidgetItem *item );
 
     protected:
-      void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+      void showEvent(QShowEvent *event) override;
 		
     private:
       enum CacheStatus { NeedRebuild, CacheOk };
